aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorSergey Poznyakoff <gray@gnu.org>2014-08-17 14:03:50 +0300
committerSergey Poznyakoff <gray@gnu.org>2014-08-17 14:15:07 +0300
commitd2b3be6e927d6585a4e9d9f7dd566763bbb6c539 (patch)
treefff626f7c69d0ecb9b532a98afea9b7ec7981c39 /src
parente45d22ab0f9e86da6f1c4985c1d200275cb2d82e (diff)
downloaddirevent-d2b3be6e927d6585a4e9d9f7dd566763bbb6c539.tar.gz
direvent-d2b3be6e927d6585a4e9d9f7dd566763bbb6c539.tar.bz2
Rename project to direvent.
Diffstat (limited to 'src')
-rw-r--r--src/.gitignore2
-rw-r--r--src/Makefile.am32
-rw-r--r--src/cmdline.opt6
-rw-r--r--src/config.c20
-rw-r--r--src/detach-bsd.c12
-rw-r--r--src/detach-darwin.c12
-rw-r--r--src/detach-std.c12
-rw-r--r--src/direvent.c (renamed from src/dircond.c)14
-rw-r--r--src/direvent.h (renamed from src/dircond.h)8
-rw-r--r--src/environ.c22
-rw-r--r--src/ev_inotify.c12
-rw-r--r--src/ev_kqueue.c12
-rw-r--r--src/event.c12
-rw-r--r--src/fnpat.c10
-rw-r--r--src/hashtab.c12
-rw-r--r--src/progman.c12
-rw-r--r--src/sigv.c12
-rw-r--r--src/watcher.c12
18 files changed, 117 insertions, 117 deletions
diff --git a/src/.gitignore b/src/.gitignore
index f6d53de..189687d 100644
--- a/src/.gitignore
+++ b/src/.gitignore
@@ -1,2 +1,2 @@
cmdline.h
-dircond
+direvent
diff --git a/src/Makefile.am b/src/Makefile.am
index d8be4b2..c7f1439 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,23 +1,23 @@
-# This file is part of Dircond -*- autoconf -*-
-# Copyright (C) 2012, 2013 Sergey Poznyakoff
+# This file is part of Direvent -*- autoconf -*-
+# Copyright (C) 2012-2014 Sergey Poznyakoff
#
-# Dircond is free software; you can redistribute it and/or modify
+# Direvent is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3, or (at your option)
# any later version.
#
-# Dircond is distributed in the hope that it will be useful,
+# Direvent is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
-# along with Dircond. If not, see <http://www.gnu.org/licenses/>.
+# along with Direvent. If not, see <http://www.gnu.org/licenses/>.
-bin_PROGRAMS=dircond
-dircond_SOURCES=\
- dircond.c\
- dircond.h\
+bin_PROGRAMS=direvent
+direvent_SOURCES=\
+ direvent.c\
+ direvent.h\
cmdline.h\
config.c\
environ.c\
@@ -28,16 +28,16 @@ dircond_SOURCES=\
progman.c\
sigv.c
-if DIRCOND_INOTIFY
- dircond_SOURCES += ev_inotify.c detach-std.c
+if DIREVENT_INOTIFY
+ direvent_SOURCES += ev_inotify.c detach-std.c
endif
-if DIRCOND_KQUEUE
- dircond_SOURCES += ev_kqueue.c
-if DIRCOND_RFORK
- dircond_SOURCES += detach-bsd.c
+if DIREVENT_KQUEUE
+ direvent_SOURCES += ev_kqueue.c
+if DIREVENT_RFORK
+ direvent_SOURCES += detach-bsd.c
else
- dircond_SOURCES += detach-darwin.c
+ direvent_SOURCES += detach-darwin.c
endif
endif
diff --git a/src/cmdline.opt b/src/cmdline.opt
index 72433a5..914922a 100644
--- a/src/cmdline.opt
+++ b/src/cmdline.opt
@@ -1,7 +1,7 @@
#define EX_USAGE 1
-OPTIONS_BEGIN("dircond",
- [<dircond monitors changes in directories>],
+OPTIONS_BEGIN("direvent",
+ [<direvent monitors changes in directories>],
[<[CONFIG]>],
[<gnu>],
[<copyright_year=2012,2013>],
@@ -74,7 +74,7 @@ help_hook(FILE *fp)
"configuration file\n"
"to use instead of %s.\n\n", DEFAULT_CONFFILE);
- fprintf(fp, "This dircond uses %s interface.\n\n", INTERFACE);
+ fprintf(fp, "This direvent uses %s interface.\n\n", INTERFACE);
}
void
diff --git a/src/config.c b/src/config.c
index b4fea6c..9c17124 100644
--- a/src/config.c
+++ b/src/config.c
@@ -1,20 +1,20 @@
/* dircond - directory content watcher daemon
Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include <grecs.h>
#include <pwd.h>
#include <grp.h>
@@ -714,7 +714,7 @@ static struct grecs_keyword watcher_kw[] = {
{ NULL }
};
-static struct grecs_keyword dircond_kw[] = {
+static struct grecs_keyword direvent_kw[] = {
{ "user", NULL, "Run as this user",
grecs_type_string, GRECS_DFLT, &user },
{ "foreground", NULL, "Run in foreground",
@@ -736,10 +736,10 @@ void
config_help()
{
static char docstring[] =
- "Configuration file structure for dircond.\n"
- "For more information, use `info dircond configuration'.";
+ "Configuration file structure for direvent.\n"
+ "For more information, use `info direvent configuration'.";
grecs_print_docstring(docstring, 0, stdout);
- grecs_print_statement_array(dircond_kw, 1, 0, stdout);
+ grecs_print_statement_array(direvent_kw, 1, 0, stdout);
}
void
@@ -751,6 +751,6 @@ config_init()
void
config_finish(struct grecs_node *tree)
{
- if (grecs_tree_process(tree, dircond_kw))
+ if (grecs_tree_process(tree, direvent_kw))
exit(1);
}
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
+/* direvent - directory content watcher daemon
Copyright (C) 2012-2014 Sergey Poznyakoff
diff --git a/src/detach-bsd.c b/src/detach-bsd.c
index be2532c..ee235b3 100644
--- a/src/detach-bsd.c
+++ b/src/detach-bsd.c
@@ -1,18 +1,18 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
/* "Early-init" detach() for BSD systems. It uses rfork instead of fork
to ensure the event queue is inherited by the child process. According
@@ -25,7 +25,7 @@
processes.
*/
-#include "dircond.h"
+#include "direvent.h"
#include <unistd.h>
#include <fcntl.h>
#include <signal.h>
diff --git a/src/detach-darwin.c b/src/detach-darwin.c
index d7209f1..924173d 100644
--- a/src/detach-darwin.c
+++ b/src/detach-darwin.c
@@ -1,18 +1,18 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
/* A "post-init" variant of detach(), used on systems where the kqueue
state cannot be inherited by the child process (most notably, Darwin).
@@ -27,7 +27,7 @@
The parent waits until a signal is delivered. It exits successfully if
delivered a SIGUSR1, and reports an error otherwise. */
-#include "dircond.h"
+#include "direvent.h"
#include <unistd.h>
#include <fcntl.h>
#include <signal.h>
diff --git a/src/detach-std.c b/src/detach-std.c
index 2a8368d..0b6ce24 100644
--- a/src/detach-std.c
+++ b/src/detach-std.c
@@ -1,24 +1,24 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
/* A standard "early-init" version of detach(). The initialization function
is called before fork. No special actions are needed to preserve the
initialized watchers' state across fork. */
-#include "dircond.h"
+#include "direvent.h"
#include <unistd.h>
#include <fcntl.h>
#include <signal.h>
diff --git a/src/dircond.c b/src/direvent.c
index 5e9805b..accf923 100644
--- a/src/dircond.c
+++ b/src/direvent.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include <stdarg.h>
#include <fcntl.h>
#include <getopt.h>
@@ -26,7 +26,7 @@
#ifndef SYSCONFDIR
# define SYSCONFDIR "/etc"
#endif
-#define DEFAULT_CONFFILE SYSCONFDIR "/dircond.conf"
+#define DEFAULT_CONFFILE SYSCONFDIR "/direvent.conf"
/* Configuration settings */
const char *program_name; /* This program name */
diff --git a/src/dircond.h b/src/direvent.h
index b215353..94702cf 100644
--- a/src/dircond.h
+++ b/src/direvent.h
@@ -1,18 +1,18 @@
/* dircond - directory content watcher daemon
Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
#include "config.h"
#include <sys/types.h>
@@ -1,18 +1,18 @@
-/* dircond - directory content watcher daemon
+/* direvent - directory content watcher daemon
Copyright (C) 2012-2014 Sergey Poznyakoff
diff --git a/src/environ.c b/src/environ.c
index a28d6b8..3c65704 100644
--- a/src/environ.c
+++ b/src/environ.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include "wordsplit.h"
extern char **environ; /* Environment */
@@ -98,11 +98,11 @@ env_concat(const char *name, size_t namelen, const char *a, const char *b)
}
static char *defenv[] = {
- "DIRCOND_SYSEV_CODE=${sysev_code}",
- "DIRCOND_SYSEV_NAME=${sysev_name}",
- "DIRCOND_GENEV_CODE=${genev_code}",
- "DIRCOND_GENEV_NAME=${genev_name}",
- "DIRCOND_FILE=${file}",
+ "DIREVENT_SYSEV_CODE=${sysev_code}",
+ "DIREVENT_SYSEV_NAME=${sysev_name}",
+ "DIREVENT_GENEV_CODE=${genev_code}",
+ "DIREVENT_GENEV_NAME=${genev_name}",
+ "DIREVENT_FILE=${file}",
NULL
};
diff --git a/src/ev_inotify.c b/src/ev_inotify.c
index 953bfeb..da388c8 100644
--- a/src/ev_inotify.c
+++ b/src/ev_inotify.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include <signal.h>
#include <sys/inotify.h>
diff --git a/src/ev_kqueue.c b/src/ev_kqueue.c
index 1c8a063..7e7d5f0 100644
--- a/src/ev_kqueue.c
+++ b/src/ev_kqueue.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include <sys/event.h>
#include <fcntl.h>
#include <signal.h>
diff --git a/src/event.c b/src/event.c
index 4959859..1350b78 100644
--- a/src/event.c
+++ b/src/event.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
struct symevt {
diff --git a/src/fnpat.c b/src/fnpat.c
index 52d64ba..3e44f12 100644
--- a/src/fnpat.c
+++ b/src/fnpat.c
@@ -1,20 +1,20 @@
/* dircond - directory content watcher daemon
Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include <fnmatch.h>
#include <grecs.h>
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
+/* direvent - directory content watcher daemon
Copyright (C) 2012-2014 Sergey Poznyakoff
diff --git a/src/hashtab.c b/src/hashtab.c
index 0e8cb7f..0649ead 100644
--- a/src/hashtab.c
+++ b/src/hashtab.c
@@ -1,20 +1,20 @@
-/* This file is part of Dircond.
- Copyright (C) 2012, 2013 Sergey Poznyakoff.
+/* This file is part of Direvent.
+ Copyright (C) 2012-2014 Sergey Poznyakoff.
- Dircond is free software; you can redistribute it and/or modify
+ Direvent is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3, or (at your option)
any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License
- along with Dircond. If not, see <http://www.gnu.org/licenses/>. */
+ along with Direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
/* |hash_size| defines a sequence of symbol table sizes. These are prime
numbers, each of which is approximately twice its predecessor. */
diff --git a/src/progman.c b/src/progman.c
index f8e45b7..cc7d4a9 100644
--- a/src/progman.c
+++ b/src/progman.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include <time.h>
#include <pwd.h>
#include <grp.h>
diff --git a/src/sigv.c b/src/sigv.c
index 649c81e..575febf 100644
--- a/src/sigv.c
+++ b/src/sigv.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
int
sigv_set_action(int sigc, int *sigv, struct sigaction *sa)
diff --git a/src/watcher.c b/src/watcher.c
index 2c80a3a..b99b5e0 100644
--- a/src/watcher.c
+++ b/src/watcher.c
@@ -1,20 +1,20 @@
-/* dircond - directory content watcher daemon
- Copyright (C) 2012, 2013 Sergey Poznyakoff
+/* direvent - directory content watcher daemon
+ Copyright (C) 2012-2014 Sergey Poznyakoff
- Dircond is free software; you can redistribute it and/or modify it
+ Direvent is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
- Dircond is distributed in the hope that it will be useful,
+ Direvent is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
You should have received a copy of the GNU General Public License along
- with dircond. If not, see <http://www.gnu.org/licenses/>. */
+ with direvent. If not, see <http://www.gnu.org/licenses/>. */
-#include "dircond.h"
+#include "direvent.h"
#include <dirent.h>
#include <sys/stat.h>

Return to:

Send suggestions and report system problems to the System administrator.